﻿#region License Information
/* HeuristicLab
 * Copyright (C) 2002-2014 Heuristic and Evolutionary Algorithms Laboratory (HEAL)
 *
 * This file is part of HeuristicLab.
 *
 * HeuristicLab is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * HeuristicLab is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HeuristicLab. If not, see <http://www.gnu.org/licenses/>.
 */
#endregion

using HeuristicLab.Common;
using HeuristicLab.Core;
using HeuristicLab.Persistence.Default.CompositeSerializers.Storable;

namespace HeuristicLab.EvolutionTracking {
  /// <summary>
  /// An arc that can have a weight, a label, and can old additional information in the Data object
  /// </summary>
  [StorableClass]
  public class Arc : Item, IArc {
    [Storable]
    private IVertex source;
    public IVertex Source { get { return source; } set { source = value; } }
    [Storable]
    private IVertex target;
    public IVertex Target { get { return target; } set { target = value; } }
    [Storable]
    private string label;
    public string Label { get { return label; } set { label = value; } }
    [Storable]
    private double weight;
    public double Weight { get { return weight; } set { weight = value; } }
    [Storable]
    private object data;
    public object Data { get { return data; } set { data = value; } }

    [StorableConstructor]
    public Arc(bool deserializing) : base(deserializing) { }

    public override IDeepCloneable Clone(Cloner cloner) {
      return new Arc(this, cloner);
    }
    public Arc() { }

    protected Arc(Arc original, Cloner cloner)
      : base(original, cloner) {
      Source = original.Source;
      Target = original.Target;
      Label = original.Label;
      Weight = original.Weight;
      Data = original.Data;
    }
  }
}
